summaryrefslogtreecommitdiff
path: root/ot/plot.py
diff options
context:
space:
mode:
Diffstat (limited to 'ot/plot.py')
-rw-r--r--ot/plot.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/ot/plot.py b/ot/plot.py
index ad436b4..3e3bed7 100644
--- a/ot/plot.py
+++ b/ot/plot.py
@@ -18,10 +18,10 @@ from matplotlib import gridspec
def plot1D_mat(a, b, M, title=''):
- """ Plot matrix M with the source and target 1D distribution
+ """ Plot matrix :math:`\mathbf{M}` with the source and target 1D distribution
- Creates a subplot with the source distribution a on the left and
- target distribution b on the tot. The matrix M is shown in between.
+ Creates a subplot with the source distribution :math:`\mathbf{a}` on the left and
+ target distribution :math:`\mathbf{b}` on the top. The matrix :math:`\mathbf{M}` is shown in between.
Parameters
@@ -61,10 +61,10 @@ def plot1D_mat(a, b, M, title=''):
def plot2D_samples_mat(xs, xt, G, thr=1e-8, **kwargs):
""" Plot matrix M in 2D with lines using alpha values
Plot lines between source and target 2D samples with a color
- proportional to the value of the matrix G between samples.
+ proportional to the value of the matrix :math:`\mathbf{G}` between samples.
Parameters
@@ -61,10 +61,10 @@ def plot1D_mat(a, b, M, title=''):
def plot2D_samples_mat(xs, xt, G, thr=1e-8, **kwargs):
- """ Plot matrix M in 2D with lines using alpha values
+ """ Plot matrix :math:`\mathbf{G}` in 2D with lines using alpha values
Plot lines between source and target 2D samples with a color